package
Version:
v0.0.0-...-021ab65
Opens a new window with list of versions in this module.
Published: Oct 28, 2024
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Data struct {
Code int `json:"code"`
Msg string `json:"msg"`
Data interface{} `json:"data"`
}
type Message struct {
Data
Stamp int64 `json:"-"`
}
Message 消息结构体
MyList 消息队列
func (l *MyList) GetBack() interface{}
GetBack 从头取
func (l *MyList) GetFront() interface{}
GetFront 从尾取
Source Files
¶
Click to show internal directories.
Click to hide internal directories.