package
Version:
v0.0.0-...-021ab65
Opens a new window with list of versions in this module.
Published: Oct 28, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ExistPlayer struct {
}
在网上找的已实现好的库 音乐播放
( 旧接口)
type MusicPlayer interface {
}
我们的接口(新接口)——音乐播放
type PlayerAdaptor struct {
}
适配器
Source Files
¶
Click to show internal directories.
Click to hide internal directories.