package
Version:
v0.0.0-...-021ab65
Opens a new window with list of versions in this module.
Published: Oct 28, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AModuleAPI interface {
TestA() string
}
AModuleAPI ...
NewAModuleAPI return new AModuleAPI
type API interface {
Test() string
}
API is facade interface of facade package
type BModuleAPI interface {
TestB() string
}
BModuleAPI ...
NewBModuleAPI return new BModuleAPI
Source Files
¶
Click to show internal directories.
Click to hide internal directories.