package
Version:
v0.0.0-...-021ab65
Opens a new window with list of versions in this module.
Published: Oct 28, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
中介者模式
中介者模式封装对象之间互交,使依赖变的简单,并且使复杂互交简单化,封装在中介者中。
例子中的中介者使用单例模式生成中介者。
中介者的change使用switch判断类型。
Documentation
¶
type CDDriver struct {
Data string
}
type SoundCard struct {
Data string
}
type VideoCard struct {
Data string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.