package
Version:
v0.0.0-...-021ab65
Opens a new window with list of versions in this module.
Published: Oct 28, 2024
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CmpMap[K, D dataType] struct {
}
func (m *CmpMap[K, D]) Del(key K)
func (m *CmpMap[K, D]) Each(f func(key K, value D))
func (m *CmpMap[K, D]) Inc(key K, count D)
func (m *CmpMap[K, D]) Set(key K, value D)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.